/*
 * @(#)LongPrintConverter.java	1.0 96/05/01 Eric Lunt
 *
 * Copyright (C) 1996 by Eric Lunt <elunt@mcs.net>.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.bdnm.mvc;

/**
 * This class will convert a Long to a String
 * and vice versa.
 *
 * @version 1.0 05/01/96
 * @author Eric Lunt
 */

public class LongPrintConverter
    implements PrintConverter {

    /**
     * Converts the given object, which I expect
     * to be a Long, to a string.
     * @param   obj the Long to convert to a String
     * @return a string representation of the Long
     */
    public String toString(Object obj) {
        if (obj == null) return "";
        try {
            return ((Number) obj).toString();
        } catch (ClassCastException e) {
            return "";
        }
    }

    /**
     * Converts a string to a generic object,
     * which the caller can cast to a Long.
     * @param   stringRep   the string to convert to
     *                      an object
     * @return the converted object
     */
    public Object fromString(String stringRep) {
        Long longValue;
        try {
            longValue = new Long(stringRep);
        } catch(NumberFormatException e) {
            longValue = new Long(0);
        }
        return longValue;
    }
}
